@@ -136,6 +136,18 @@ OPERATION_SHAPES = {
                         'description': 'Custom configuration version number'
                     }
                 }
+            },
+            'inboundHostname': {
+                'type': 'string',
+                'description':
+                    'The FQDN of inbound host or just the prefix part of the hostname'
+            },
+            'listenComponents': {
+                'type': 'array',
+                'description': 'Listen components port and protocol data',
+                'items': {
+                    '$ref': '#/definitions/ListenComponent'
+                }
             }
         }
     },
@@ -261,6 +273,22 @@ OPERATION_SHAPES = {
                 }
             }
         }
+    },
+    'ListenComponent': {
+        'type': 'object',
+        'required': ['protocol', 'port'],
+        'properties': {
+            'protocol': {
+                'type': 'string',
+                'description': 'Inbound protocol',
+                'enum': ['TCP', 'UDP']
+            },
+            'port': {
+                'type': 'string',
+                'description': 'Inbound port'
+            }
+        },
+        'description': 'Provides subset of metadata of a Listen* component'
     }
 }
 
@@ -312,11 +340,12 @@ class CreateDeploymentOperationCaller(CLIOperationCaller):
         df_client = client_creator('df')
 
         service_crn = parameters.get('serviceCrn', None)
-        environment_crn = self._get_environment_crn(df_client, service_crn)
         flow_version_crn = parameters.get('flowVersionCrn', None)
         deployment_request_crn = self._initiate_deployment(
                 df_client, service_crn, flow_version_crn)
 
+        environment_crn = self._get_environment_crn(df_client, service_crn)
+
         iam_client = client_creator('iam')
         set_workload_access_token(iam_client, parsed_globals, SERVICE_NAME.upper(),
                                   environment_crn)
@@ -445,6 +474,12 @@ class CreateDeploymentOperationCaller(CLIOperationCaller):
             'staticNodeCount': parameters.get('staticNodeCount', 1)
         }
 
+        inboundHostname = parameters.get('inboundHostname', None)
+        if inboundHostname is not None:
+            deployment_configuration['inboundHostname'] = inboundHostname
+            deployment_configuration['listenComponents'] = \
+                parameters.get('listenComponents', None)
+
         autoScalingEnabled = parameters.get('autoScalingEnabled', None)
         if autoScalingEnabled is not None:
             deployment_configuration['autoScalingEnabled'] = autoScalingEnabled
